@@ -280,6 +280,11 @@ public class MetadataIndexEngine implements MetaIndexEngine {
                                             callback));
     }
 
+    @Override
+    public boolean isAlive() {
+        return this.provider.isAlive();
+    }
+
     @Override
     public int priority() {
         return 50;
