@@ -32,11 +32,11 @@ import org.junit.runner.RunWith;
 import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.widget.dnd.GridWidgetDnDHandlersState;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.NodeMouseEventHandler;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.GridRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.impl.BaseGridRendererHelper;
-import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.DefaultGridLayer;
 
 import static org.mockito.Matchers.any;
@@ -58,9 +58,6 @@ public abstract class BaseGridWidgetMouseDoubleClickHandlerTest {
     @Mock
     protected DefaultGridLayer layer;
 
-    @Mock
-    protected GridSelectionManager selectionManager;
-
     @Mock
     protected GridData uiModel;
 
@@ -85,6 +82,9 @@ public abstract class BaseGridWidgetMouseDoubleClickHandlerTest {
     @Mock
     private NodeMouseEventHandler eventHandler;
 
+    @Mock
+    private GridWidgetDnDHandlersState state;
+
     protected NodeMouseDoubleClickEvent event;
 
     private BaseGridWidgetMouseDoubleClickHandler mouseDoubleClickHandler;
@@ -99,6 +99,7 @@ public abstract class BaseGridWidgetMouseDoubleClickHandlerTest {
         when(gridWidget.getRendererHelper()).thenReturn(helper);
         when(gridWidget.getLayer()).thenReturn(layer);
         when(gridWidget.getHeader()).thenReturn(header);
+        when(gridWidget.getComputedLocation()).thenReturn(new Point2D(0.0, 0.0));
         when(renderer.getHeaderHeight()).thenReturn(64.0);
         when(renderer.getHeaderRowHeight()).thenReturn(32.0);
         when(uiModel.getHeaderRowCount()).thenReturn(2);
@@ -107,6 +108,9 @@ public abstract class BaseGridWidgetMouseDoubleClickHandlerTest {
             add(uiColumn);
         }});
 
+        when(state.getOperation()).thenReturn(GridWidgetDnDHandlersState.GridWidgetHandlersOperation.NONE);
+        when(layer.getGridWidgetHandlersState()).thenReturn(state);
+
         final BaseGridRendererHelper.RenderingInformation ri = BaseGridWidgetRenderingTestUtils.makeRenderingInformation(uiModel, Collections.emptyList());
         when(helper.getRenderingInformation()).thenReturn(ri);
 
