@@ -57,6 +57,14 @@ public interface Moment {
 
     Double valueOf();
 
+    int hours();
+
+    int minutes();
+
+    int seconds();
+
+    boolean isValid();
+
     @JsOverlay
     default Long asLong(){
         return valueOf().longValue();
@@ -80,6 +88,9 @@ public interface Moment {
             return moment(new Double(time));
         }
 
+        @JsMethod(namespace = JsPackage.GLOBAL)
+        public static native Moment moment(String time, String format);
+
         @JsMethod(namespace = JsPackage.GLOBAL)
         protected static native Moment moment(Double time);
     }
