@@ -18,6 +18,7 @@ package org.uberfire.client.workbench.widgets.menu;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.function.Consumer;
 
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Test;
@@ -183,7 +184,10 @@ public class WorkbenchMenuBarPresenterTest {
         final PlaceRequest placeRequest = mock(PlaceRequest.class);
 
         when(activity.getIdentifier()).thenReturn(PERSPECTIVE_ID);
-        when(activity.getMenus()).thenReturn(contextMenus);
+        doAnswer(invocationOnMock -> {
+            invocationOnMock.getArgumentAt(0, Consumer.class).accept(contextMenus);
+            return null;
+        }).when(activity).getMenus(any());
         when(activity.isType(ActivityResourceType.PERSPECTIVE.name())).thenReturn(true);
         when(authzManager.authorize(contextMenus.getItems().get(0),
                                     identity)).thenReturn(true);
@@ -212,7 +216,10 @@ public class WorkbenchMenuBarPresenterTest {
         final PlaceRequest placeRequest = mock(PlaceRequest.class);
 
         when(activity.getIdentifier()).thenReturn(PERSPECTIVE_ID);
-        when(activity.getMenus()).thenReturn(contextMenus);
+        doAnswer(invocationOnMock -> {
+            invocationOnMock.getArgumentAt(0, Consumer.class).accept(contextMenus);
+            return null;
+        }).when(activity).getMenus(any());
         when(activity.isType(ActivityResourceType.PERSPECTIVE.name())).thenReturn(true);
         when(authzManager.authorize(contextMenus.getItems().get(0),
                                     identity)).thenReturn(false);
@@ -295,7 +302,10 @@ public class WorkbenchMenuBarPresenterTest {
         final PlaceRequest placeRequest = mock(PlaceRequest.class);
 
         when(activity.getIdentifier()).thenReturn(PERSPECTIVE_ID);
-        when(activity.getMenus()).thenReturn(contextMenus);
+        doAnswer(invocationOnMock -> {
+            invocationOnMock.getArgumentAt(0, Consumer.class).accept(contextMenus);
+            return null;
+        }).when(activity).getMenus(any());
         when(activity.isType(ActivityResourceType.PERSPECTIVE.name())).thenReturn(true);
         when(authzManager.authorize(contextMenus.getItems().get(0),
                                     identity)).thenReturn(true);
